@@ -1,6 +1,6 @@
 #! /bin/bash -e
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-18 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 #
 # CppAD is distributed under the terms of the
 #              Eclipse Public License Version 2.0.
@@ -15,6 +15,14 @@ then
     echo 'bin/appveyor.sh: must be executed from its parent directory'
     exit 1
 fi
+if [ "$1" != 'make' ] && [ "$1" != 'test_one' ]
+then
+    echo 'usage: bin/travis.sh (make|test_one) target1 target2 ...'
+    echo 'target: if make specified, is one of the available make commands'
+    echo          if test_one, specified, is the path to a test file.
+    exit 1
+fi
+cmd="$1"
 # -----------------------------------------------------------------------------
 # bash function that echos and executes a command
 echo_eval() {
@@ -22,16 +30,36 @@ echo_eval() {
     eval $*
 }
 # -----------------------------------------------------------------------------
+if [ -e build ]
+then
+    echo_eval rm -r build
+fi
 echo_eval mkdir build
 echo_eval cd build
 echo_eval cmake \
     -G '"Unix Makefiles"' \
+    -D cppad_prefix=$(pwd)/prefix \
     -D CMAKE_C_COMPILER=gcc \
     -D CMAKE_CXX_COMPILER=g++ \
     ..
-echo_eval make check
-echo_eval make install
-echo_eval make uninstall
+# -----------------------------------------------------------------------------
+if [ "$cmd" == 'make' ]
+then
+    shift
+    while [ "$1" != '' ]
+    do
+        echo_eval make "$1"
+        shift
+    done
+else
+    echo_eval cd ..
+    shift
+    while [ "$1" != '' ]
+    do
+        echo_eval bin/test_one.sh "$1"
+        shift
+    done
+fi
 # -----------------------------------------------------------------------------
 echo 'bin/appveyor.sh: OK'
 exit 0
