@@ -1,7 +1,7 @@
 # ifndef CPPAD_EXAMPLE_ABS_NORMAL_QP_INTERIOR_HPP
 # define CPPAD_EXAMPLE_ABS_NORMAL_QP_INTERIOR_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -35,7 +35,7 @@ $icode%ok% = qp_interior(
 )%$$
 
 $head Prototype$$
-$srcfile%example/abs_normal/qp_interior.hpp%
+$srcthisfile%
     0%// BEGIN PROTOTYPE%// END PROTOTYPE%
 1%$$
 
