@@ -1,5 +1,5 @@
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -20,7 +20,7 @@ $$
 $section The AD erf Function: Example and Test$$
 
 
-$srcfile%example/general/erf.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcthisfile%0%// BEGIN C++%// END C++%1%$$
 
 $end
 */
@@ -57,10 +57,8 @@ bool erf(void)
     // check relative erorr
     double erf_x0 = 0.5204998778130465;
     ok &= NearEqual(ay[0] , erf_x0,  0.,    4e-4);
-# if CPPAD_USE_CPLUSPLUS_2011
     double tmp = std::max(1e-15, eps);
     ok &= NearEqual(ay[0] , erf_x0,  0.,    tmp);
-# endif
 
     // value of derivative of erf at x0
     double pi     = 4. * std::atan(1.);
@@ -73,9 +71,7 @@ bool erf(void)
     dx[0] = 1.;
     dy    = f.Forward(1, dx);
     ok   &= NearEqual(dy[0], check,  0.,  1e-3);
-# if CPPAD_USE_CPLUSPLUS_2011
     ok   &= NearEqual(dy[0], check,  0.,  eps);
-# endif
 
     // reverse computation of derivative of y[0]
     CPPAD_TESTVECTOR(double)  w(m);
@@ -83,9 +79,7 @@ bool erf(void)
     w[0]  = 1.;
     dw    = f.Reverse(1, w);
     ok   &= NearEqual(dw[0], check,  0., 1e-1);
-# if CPPAD_USE_CPLUSPLUS_2011
     ok   &= NearEqual(dw[0], check,  0., eps);
-# endif
 
     // use a VecAD<Base>::reference object with erf
     CppAD::VecAD<double> v(1);
