@@ -1,7 +1,7 @@
 # ifndef CPPAD_CORE_ABS_NORMAL_FUN_HPP
 # define CPPAD_CORE_ABS_NORMAL_FUN_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-21 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -257,13 +257,15 @@ y( x , a(x ) ) & = & b + J x + Y |z( x , a(x ) )|
 \end{array}
 \] $$
 This is Equation (2) of the
-$cref/reference/abs_normal/Reference/$$.
+$cref/reference/example_abs_normal/Reference/$$.
 
-$children%example/abs_normal/get_started.cpp
+$children%example/abs_normal/abs_normal.omh
 %$$
 $head Example$$
 The file $cref abs_get_started.cpp$$ contains
 an example and test using this operation.
+The section $cref example_abs_normal$$
+has a links to all the abs normal examples.
 
 $end
 -------------------------------------------------------------------------------
@@ -305,7 +307,7 @@ void ADFun<Base,RecBase>::abs_normal_fun(ADFun& g, ADFun& a) const
     CppAD::vector<size_t> f_abs_res;
     //
     OpCode        op;                 // this operator
-    const addr_t* arg = CPPAD_NULL;   // arguments for this operator
+    const addr_t* arg = nullptr;   // arguments for this operator
     size_t        i_var;              // variable index for this operator
     local::play::const_sequential_iterator itr = play_.begin();
     itr.op_info(op, arg, i_var);
@@ -413,7 +415,7 @@ void ADFun<Base,RecBase>::abs_normal_fun(ADFun& g, ADFun& a) const
     //
     // mapping from old variable index to new variable index
     CPPAD_ASSERT_UNKNOWN(
-        size_t( std::numeric_limits<addr_t>::max() ) >= num_var
+        size_t( (std::numeric_limits<addr_t>::max)() ) >= num_var
     );
     CppAD::vector<addr_t> f2g_var(num_var);
     for(i_var = 0; i_var < num_var; i_var++)
@@ -538,7 +540,14 @@ void ADFun<Base,RecBase>::abs_normal_fun(ADFun& g, ADFun& a) const
             case DivvpOp:
             case PowvpOp:
             case ZmulvpOp:
-            CPPAD_ASSERT_NARG_NRES(op, 2, 1);
+# ifndef NDEBUG
+            if( op == PowvpOp )
+            {   CPPAD_ASSERT_NARG_NRES(op, 2, 3);
+            }
+            else
+            {   CPPAD_ASSERT_NARG_NRES(op, 2, 1);
+            }
+# endif
             CPPAD_ASSERT_UNKNOWN( size_t( f2g_var[ arg[0] ] ) < num_var );
             new_arg[0] = f2g_var[ arg[0] ];
             new_arg[1] = arg[1]; // parameter
@@ -563,7 +572,14 @@ void ADFun<Base,RecBase>::abs_normal_fun(ADFun& g, ADFun& a) const
             case DivpvOp:
             case PowpvOp:
             case ZmulpvOp:
-            CPPAD_ASSERT_NARG_NRES(op, 2, 1);
+# ifndef NDEBUG
+            if( op == PowpvOp )
+            {   CPPAD_ASSERT_NARG_NRES(op, 2, 3);
+            }
+            else
+            {   CPPAD_ASSERT_NARG_NRES(op, 2, 1);
+            }
+# endif
             CPPAD_ASSERT_UNKNOWN( size_t( f2g_var[ arg[1] ] ) < num_var );
             new_arg[0] = arg[0]; // parameter
             new_arg[1] = f2g_var[ arg[1] ];
@@ -576,8 +592,16 @@ void ADFun<Base,RecBase>::abs_normal_fun(ADFun& g, ADFun& a) const
             case SubvvOp:
             case MulvvOp:
             case DivvvOp:
+            case PowvvOp:
             case ZmulvvOp:
-            CPPAD_ASSERT_NARG_NRES(op, 2, 1);
+# ifndef NDEBUG
+            if( op == PowvvOp )
+            {   CPPAD_ASSERT_NARG_NRES(op, 2, 3);
+            }
+            else
+            {   CPPAD_ASSERT_NARG_NRES(op, 2, 1);
+            }
+# endif
             CPPAD_ASSERT_UNKNOWN( size_t( f2g_var[ arg[0] ] ) < num_var );
             CPPAD_ASSERT_UNKNOWN( size_t( f2g_var[ arg[1] ] ) < num_var );
             new_arg[0] = f2g_var[ arg[0] ];
@@ -833,7 +857,7 @@ void ADFun<Base,RecBase>::abs_normal_fun(ADFun& g, ADFun& a) const
     // Check a few expected results
     CPPAD_ASSERT_UNKNOWN( rec.num_op_rec() == play_.num_op_rec() );
     CPPAD_ASSERT_UNKNOWN( rec.num_var_rec() == play_.num_var_rec() );
-    CPPAD_ASSERT_UNKNOWN( rec.num_load_op_rec() == play_.num_load_op_rec() );
+    CPPAD_ASSERT_UNKNOWN( rec.num_var_load_rec() == play_.num_var_load_rec() );
 
     // -----------------------------------------------------------------------
     // Use rec to create the function g
