@@ -1,7 +1,7 @@
 # ifndef CPPAD_CORE_ATOMIC_ATOMIC_THREE_HPP
 # define CPPAD_CORE_ATOMIC_ATOMIC_THREE_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -392,7 +392,7 @@ public:
     {   bool        set_null = false;
         size_t      type  = 0;          // set to avoid warning
         std::string name;
-        void*       v_ptr = CPPAD_NULL; // set to avoid warning
+        void*       v_ptr = nullptr; // set to avoid warning
         local::atomic_index<Base>(set_null, index_, type, &name, v_ptr);
         CPPAD_ASSERT_UNKNOWN( type == 3 );
         return name;
@@ -403,8 +403,8 @@ public:
     {   // change object pointer to null, but leave name for error reporting
         bool         set_null = true;
         size_t       type  = 0;          // set to avoid warning
-        std::string* name  = CPPAD_NULL;
-        void*        v_ptr = CPPAD_NULL; // set to avoid warning
+        std::string* name  = nullptr;
+        void*        v_ptr = nullptr; // set to avoid warning
         local::atomic_index<Base>(set_null, index_, type, name, v_ptr);
         CPPAD_ASSERT_UNKNOWN( type == 3 );
         //
@@ -414,7 +414,7 @@ public:
     }
     /// allocates work_ for a specified thread
     void allocate_work(size_t thread)
-    {   if( work_[thread] == CPPAD_NULL )
+    {   if( work_[thread] == nullptr )
         {   // allocate the raw memory
             size_t min_bytes = sizeof(work_struct);
             size_t num_bytes;
@@ -428,7 +428,7 @@ public:
     }
     /// frees work_ for a specified thread
     void free_work(size_t thread)
-    {   if( work_[thread] != CPPAD_NULL )
+    {   if( work_[thread] != nullptr )
         {   // call destructor
             work_[thread]->~work_struct();
             // return memory to avialable pool for this thread
@@ -436,7 +436,7 @@ public:
                 reinterpret_cast<void*>(work_[thread])
             );
             // mark this thread as not allocated
-            work_[thread] = CPPAD_NULL;
+            work_[thread] = nullptr;
         }
         return;
     }
@@ -444,8 +444,8 @@ public:
     static atomic_three* class_object(size_t index)
     {   bool         set_null = false;
         size_t       type  = 0;          // set to avoid warning
-        std::string* name  = CPPAD_NULL;
-        void*        v_ptr = CPPAD_NULL; // set to avoid warning
+        std::string* name  = nullptr;
+        void*        v_ptr = nullptr; // set to avoid warning
         local::atomic_index<Base>(set_null, index, type, name, v_ptr);
         CPPAD_ASSERT_UNKNOWN( type == 3 );
         return reinterpret_cast<atomic_three*>( v_ptr );
@@ -455,7 +455,7 @@ public:
     {   bool        set_null = false;
         size_t      type  = 0;          // set to avoid warning
         std::string name;
-        void*       v_ptr = CPPAD_NULL; // set to avoid warning
+        void*       v_ptr = nullptr; // set to avoid warning
         local::atomic_index<Base>(set_null, index, type, &name, v_ptr);
         CPPAD_ASSERT_UNKNOWN( type == 3 );
         return name;
