@@ -136,10 +136,10 @@ azmul(const AD<Base>& x, const AD<Base>& y)
             result.tape_id_ = tape_id;
             result.ad_type_ = variable_enum;
         }
-        else if( IdenticalZero( y.value_ ) )
+        else if( ( ! dyn_y ) & IdenticalZero( y.value_ ) )
         {   // result = variable * 0
         }
-        else if( IdenticalOne( y.value_ ) )
+        else if( ( ! dyn_y ) & IdenticalOne( y.value_ ) )
         {   // result = variable * 1
             result.make_variable(x.tape_id_, x.taddr_);
         }
@@ -163,10 +163,10 @@ azmul(const AD<Base>& x, const AD<Base>& y)
         }
     }
     else if( var_y )
-    {   if( IdenticalZero(x.value_) )
+    {   if( ( ! dyn_x ) & IdenticalZero(x.value_) )
         {   // result = 0 * variable
         }
-        else if( IdenticalOne( x.value_ ) )
+        else if( ( ! dyn_x ) & IdenticalOne( x.value_ ) )
         {   // result = 1 * variable
             result.make_variable(y.tape_id_, y.taddr_);
         }
