@@ -1,7 +1,7 @@
 # ifndef CPPAD_CORE_BASE2AD_HPP
 # define CPPAD_CORE_BASE2AD_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-18 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -73,9 +73,6 @@ namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 template <class Base, class RecBase>
 ADFun< AD<Base>, RecBase > ADFun<Base,RecBase>::base2ad(void) const
 {   ADFun< AD<Base>, RecBase > fun;
-    //
-    // This is a base2ad return value and only case where this flag is true
-    fun.base2ad_return_value_      = true;
     //
     // bool values
     fun.has_been_optimized_        = has_been_optimized_;
@@ -95,13 +92,13 @@ ADFun< AD<Base>, RecBase > ADFun<Base,RecBase>::base2ad(void) const
     fun.dep_taddr_                 = dep_taddr_;
     fun.dep_parameter_             = dep_parameter_;
     fun.cskip_op_                  = cskip_op_;
-    fun.load_op_                   = load_op_;
+    fun.load_op2var_               = load_op2var_;
     //
     // pod_maybe_vector< AD<Base> > = pod_maybe_vector<Base>
     CPPAD_ASSERT_UNKNOWN( fun.taylor_.size() == 0 );
     //
     // player
-    // (uses move semantics when CPPAD_USE_CPLUSPLUS_2011 is 1)
+    // (uses move semantics)
     fun.play_ = play_.base2ad();
     //
     // subgraph
