@@ -1,7 +1,7 @@
 # ifndef CPPAD_LOCAL_LOAD_OP_HPP
 # define CPPAD_LOCAL_LOAD_OP_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -28,6 +28,7 @@ $spell
     arg
     num
     Addr
+    vecad
 $$
 $section Accessing an Element in a Variable VecAD Vector$$
 
@@ -44,14 +45,14 @@ $codei%forward_load_%I%_op_0(
     %taylor%,
     %vec_ad2isvar%,
     %vec_ad2index%,
-    %var_by_load_op%
+    %load_op2var%
 )
 %$$
 where the index type $icode I$$ is $code p$$ (for parameter)
 or $code v$$ (for variable).
 
 $head Prototype$$
-$srcfile%include/cppad/local/load_op.hpp%
+$srcthisfile%
     0%// BEGIN_FORWARD_LOAD_P_OP_0%// END_FORWARD_LOAD_P_OP_0%1
 %$$
 The prototype for $code forward_load_v_op_0$$ is the same
@@ -72,12 +73,12 @@ corresponding to $icode x$$.
 
 $subhead n_load$$
 This is the number of load instructions in this recording; i.e.,
-$icode%play%->num_load_op_rec()%$$.
+$icode%play%->num_var_load_rec()%$$.
 
 $subhead n_all$$
 This is the number of values in the single array that includes
 all the vectors together with the size of each vector; i.e.,
-$icode%play%->num_vec_ind_rec()%$$.
+$icode%play%->num_var_vecad_ind_rec()%$$.
 
 $head Addr$$
 Is the type used for address on this tape.
@@ -107,7 +108,7 @@ corresponding to $cref/i_vec/load_op_var/Notation/i_vec/$$.
 
 $subhead arg[2]$$
 Is the index of this VecAD load instruction in the
-$icode var_by_load_op$$ array.
+$icode load_op2var$$ array.
 
 $head parameter$$
 This is the vector of parameters for this recording which has size
@@ -149,16 +150,16 @@ is the number of elements in the user vector containing this load.
 $icode%vec_ad2index%[%i_pv%]%$$ is the variable or
 parameter index for this element,
 
-$head var_by_load_op$$
+$head load_op2var$$
 is a vector with size $icode n_load$$.
 The input value of its elements does not matter.
 If the result of this load is a variable,
 $codei%
-    %var_by_load_op%[%arg%[2]] = %i_pv%
+    %load_op2var%[%arg%[2]] = %i_pv%
 %$$
 Otherwise,
 $codei%
-    %var_by_load_op%[%arg%[2]] = 0
+    %load_op2var%[%arg%[2]] = 0
 %$$
 
 $end
@@ -174,13 +175,13 @@ void forward_load_p_op_0(
     Base*          taylor           ,
     const bool*    vec_ad2isvar     ,
     const size_t*  vec_ad2index     ,
-    Addr*          var_by_load_op   )
+    Addr*          load_op2var   )
 // END_FORWARD_LOAD_P_OP_0
 {   CPPAD_ASSERT_UNKNOWN( NumArg(LdpOp) == 3 );
     CPPAD_ASSERT_UNKNOWN( NumRes(LdpOp) == 1 );
     CPPAD_ASSERT_UNKNOWN( 0 < arg[0] );
     CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < play->num_par_rec() );
-    CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < play->num_load_op_rec() );
+    CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < play->num_var_load_rec() );
     CPPAD_ASSERT_UNKNOWN(
         size_t( std::numeric_limits<addr_t>::max() ) >= i_z
     );
@@ -190,19 +191,19 @@ void forward_load_p_op_0(
         size_t(i_vec) < vec_ad2index[ arg[0] - 1 ] ,
         "VecAD: dynamic parmaeter index out or range during zero order forward"
     );
-    CPPAD_ASSERT_UNKNOWN( size_t(arg[0] + i_vec) < play->num_vec_ind_rec() );
+    CPPAD_ASSERT_UNKNOWN( size_t(arg[0] + i_vec) < play->num_var_vecad_ind_rec() );
 
     size_t i_pv   = vec_ad2index[ arg[0] + i_vec ];
     Base* z       = taylor + i_z * cap_order;
     if( vec_ad2isvar[ arg[0] + i_vec ]  )
     {   CPPAD_ASSERT_UNKNOWN( i_pv < i_z );
-        var_by_load_op[ arg[2] ] = addr_t( i_pv );
+        load_op2var[ arg[2] ] = addr_t( i_pv );
         Base* v_x = taylor + i_pv * cap_order;
         z[0]      = v_x[0];
     }
     else
     {   CPPAD_ASSERT_UNKNOWN( i_pv < play->num_par_rec()  );
-        var_by_load_op[ arg[2] ] = 0;
+        load_op2var[ arg[2] ] = 0;
         Base v_x  = parameter[i_pv];
         z[0]      = v_x;
     }
@@ -217,12 +218,12 @@ void forward_load_v_op_0(
     Base*          taylor           ,
     const bool*    vec_ad2isvar     ,
     const size_t*  vec_ad2index     ,
-    Addr*          var_by_load_op   )
+    Addr*          load_op2var   )
 {   CPPAD_ASSERT_UNKNOWN( NumArg(LdvOp) == 3 );
     CPPAD_ASSERT_UNKNOWN( NumRes(LdvOp) == 1 );
     CPPAD_ASSERT_UNKNOWN( 0 < arg[0] );
     CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
-    CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < play->num_load_op_rec() );
+    CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < play->num_var_load_rec() );
     CPPAD_ASSERT_UNKNOWN(
         size_t( std::numeric_limits<addr_t>::max() ) >= i_z
     );
@@ -232,19 +233,19 @@ void forward_load_v_op_0(
         size_t(i_vec) < vec_ad2index[ arg[0] - 1 ] ,
         "VecAD: variable index out or range during zero order forward"
     );
-    CPPAD_ASSERT_UNKNOWN( size_t(arg[0] + i_vec) < play->num_vec_ind_rec() );
+    CPPAD_ASSERT_UNKNOWN( size_t(arg[0] + i_vec) < play->num_var_vecad_ind_rec() );
 
     size_t i_pv   = vec_ad2index[ arg[0] + i_vec ];
     Base* z       = taylor + i_z * cap_order;
     if( vec_ad2isvar[ arg[0] + i_vec ]  )
     {   CPPAD_ASSERT_UNKNOWN( i_pv < i_z );
-        var_by_load_op[ arg[2] ] = addr_t( i_pv );
+        load_op2var[ arg[2] ] = addr_t( i_pv );
         Base* v_x = taylor + i_pv * cap_order;
         z[0]      = v_x[0];
     }
     else
     {   CPPAD_ASSERT_UNKNOWN( i_pv < play->num_par_rec() );
-        var_by_load_op[ arg[2] ] = 0;
+        load_op2var[ arg[2] ] = 0;
         Base v_x  = parameter[i_pv];
         z[0]      = v_x;
     }
@@ -387,10 +388,10 @@ is the AD variable index corresponding to the variable z.
 
 \param arg
 arg[2]
-Is the index of this vecad load instruction in the var_by_load_op array.
+Is the index of this vecad load instruction in the load_op2var array.
 
-\param var_by_load_op
-is a vector with size play->num_load_op_rec().
+\param load_op2var
+is a vector with size play->num_var_load_rec().
 It contains the variable index corresponding to each load instruction.
 In the case where the index is zero,
 the instruction corresponds to a parameter (not variable).
@@ -398,7 +399,7 @@ the instruction corresponds to a parameter (not variable).
 \par i_var
 We use the notation
 \verbatim
-    i_var = size_t( var_by_load_op[ arg[2] ] )
+    i_var = size_t( load_op2var[ arg[2] ] )
 \endverbatim
 
 \param taylor
@@ -427,7 +428,7 @@ void forward_load_op(
     size_t               cap_order            ,
     size_t               i_z                  ,
     const Addr*          arg                  ,
-    const Addr*          var_by_load_op       ,
+    const Addr*          load_op2var       ,
           Base*          taylor               )
 {
     CPPAD_ASSERT_UNKNOWN( NumArg(op) == 3 );
@@ -436,9 +437,9 @@ void forward_load_op(
     CPPAD_ASSERT_UNKNOWN( 0 < r);
     CPPAD_ASSERT_UNKNOWN( 0 < p);
     CPPAD_ASSERT_UNKNOWN( p <= q );
-    CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < play->num_load_op_rec() );
+    CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < play->num_var_load_rec() );
 
-    size_t i_var = size_t( var_by_load_op[ arg[2] ] );
+    size_t i_var = size_t( load_op2var[ arg[2] ] );
     CPPAD_ASSERT_UNKNOWN( i_var < i_z );
 
     size_t num_taylor_per_var = (cap_order-1) * r + 1;
@@ -505,7 +506,7 @@ is the AD variable index corresponding to the variable z.
 \param arg
  arg[2]
 Is the index of this vecad load instruction in the
-var_by_load_op array.
+load_op2var array.
 
 \param cap_order
 number of columns in the matrix containing the Taylor coefficients
@@ -538,8 +539,8 @@ the k-th order Taylor coefficient for x.
 On input, it corresponds to the function G,
 and on output it corresponds to the the function H.
 
-\param var_by_load_op
-is a vector with size play->num_load_op_rec().
+\param load_op2var
+is a vector with size play->num_var_load_rec().
 It contains the variable index corresponding to each load instruction.
 In the case where the index is zero,
 the instruction corresponds to a parameter (not variable).
@@ -560,8 +561,8 @@ void reverse_load_op(
     const Base*    taylor      ,
     size_t         nc_partial  ,
     Base*          partial     ,
-    const Addr*          var_by_load_op )
-{   size_t i_load = size_t( var_by_load_op[ arg[2] ] );
+    const Addr*          load_op2var )
+{   size_t i_load = size_t( load_op2var[ arg[2] ] );
 
     CPPAD_ASSERT_UNKNOWN( NumArg(op) == 3 );
     CPPAD_ASSERT_UNKNOWN( NumRes(op) == 1 );
