@@ -1,7 +1,7 @@
 # ifndef CPPAD_LOCAL_OPTIMIZE_GET_OP_USAGE_HPP
 # define CPPAD_LOCAL_OPTIMIZE_GET_OP_USAGE_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -11,11 +11,6 @@ Secondary License when the conditions for such availability set forth
 in the Eclipse Public License, Version 2.0 are satisfied:
       GNU General Public License, Version 2.0 or later.
 ---------------------------------------------------------------------------- */
-/*!
-\file get_cexp_info.hpp
-Create operator information tables
-*/
-
 # include <cppad/local/optimize/cexp_info.hpp>
 # include <cppad/local/optimize/usage.hpp>
 # include <cppad/local/sweep/call_atomic.hpp>
@@ -52,6 +47,7 @@ $spell
     op
     arg
     csum
+    optimizer
 $$
 
 $section
@@ -59,7 +55,7 @@ Increase Argument Usage and Propagate cexp_set From Result to Argument
 $$
 
 $head Prototype$$
-$srcfile%include/cppad/local/optimize/get_op_usage.hpp%
+$srcthisfile%
     0%// BEGIN_OP_INC_ARG_USAGE%// END_PROTOTYPE%1
 %$$
 
@@ -67,9 +63,9 @@ $srcfile%include/cppad/local/optimize/get_op_usage.hpp%
 $head play$$
 is the player for the old operation sequence.
 
-$head sum_result$$
-is result an addition or subtraction operator (passed for speed so
-do not need to call $code op_add_or_sub$$ for result.
+$head check_csum$$
+is result an addition or subtraction operator,
+and the optimizer is allowed to generate cumulative sum operators.
 
 $head i_result$$
 is the operator index for the result operator.
@@ -82,7 +78,7 @@ There may be postings waiting to be processed for the corresponding cexp_set.
 $head op_usage$$
 structure that holds the information for each of the operators.
 The output value of op_usage[i_arg] is increased; to be specific,
-If sum_result is true and the input value of op_usage[i_arg]
+If check_csum is true and the input value of op_usage[i_arg]
 is usage_t(no_usage), its output value is usage_t(csum_usage).
 Otherwise, the output value of op_usage[i_arg] is usage_t(yes_usage).
 
@@ -112,7 +108,7 @@ $end
 template <class Base>
 void op_inc_arg_usage(
     const player<Base>*         play           ,
-    bool                        sum_result     ,
+    bool                        check_csum     ,
     size_t                      i_result       ,
     size_t                      i_arg          ,
     pod_vector<usage_t>&        op_usage       ,
@@ -123,7 +119,7 @@ void op_inc_arg_usage(
     //
     // new value for usage
     op_usage[i_arg] = usage_t(yes_usage);
-    if( sum_result )
+    if( check_csum )
     {   if( arg_usage == no_usage )
         {   OpCode op_a = play->GetOp(i_arg);
             if( op_add_or_sub( op_a ) )
@@ -174,7 +170,7 @@ Use Reverse Activity Analysis to Get Usage Information for Each Operator
 $$
 
 $head Prototype$$
-$srcfile%include/cppad/local/optimize/get_op_usage.hpp%
+$srcthisfile%
     0%// BEGIN_GET_OP_USAGE%// END_PROTOTYPE%1
 %$$
 
@@ -186,11 +182,9 @@ using type $icode Base$$.
 $head Addr$$
 Type used by random iterator for the player.
 
-$head conditional_skip$$
-If this is true,
-the conditional expression information cexp_info will be calculated.
-This may be time intensive and may not have much benefit in the optimized
-recording.
+$head cumulative_sum_op$$
+If this is true (false), cumulative summation operator are allowed
+(not allowed) to be generated by the optimization.
 
 $head compare_op$$
 if this is true, arguments are considered used if they appear in compare
@@ -203,6 +197,13 @@ if this is true, arguments are considered used if they appear in
 print forward operators; i.e., PriOp.
 This is also a side effect; i.e. NumRes(PriOp) is zero.
 
+$head conditional_skip$$
+If this is true,
+the conditional expression information cexp_info will be calculated.
+This may be time intensive and may not have much benefit in the optimized
+recording.
+
+
 $head play$$
 This is the operation sequence.
 
@@ -231,7 +232,7 @@ Note that j indexes the CExpOp operators in the operation sequence.
 $head vecad_used$$
 The input size of this vector must be zero.
 Upon return it has size equal to the number of VecAD vectors
-in the operations sequences; i.e., play->num_vecad_vec_rec().
+in the operations sequences; i.e., play->num_var_vecad_rec().
 The VecAD vectors are indexed in the order that their indices appear
 in the one large play->GetVecInd that holds all the VecAD vectors.
 
@@ -255,6 +256,7 @@ void get_op_usage(
     bool                                        conditional_skip    ,
     bool                                        compare_op          ,
     bool                                        print_for_op        ,
+    bool                                        cumulative_sum_op   ,
     const player<Base>*                         play                ,
     const play::const_random_iterator<Addr>&    random_itr          ,
     const pod_vector<size_t>&                   dep_taddr           ,
@@ -273,7 +275,7 @@ void get_op_usage(
     //
     // initialize mapping from variable index to operator index
     CPPAD_ASSERT_UNKNOWN(
-        size_t( std::numeric_limits<addr_t>::max() ) >= num_op
+        size_t( (std::numeric_limits<addr_t>::max)() ) >= num_op
     );
     // -----------------------------------------------------------------------
     // information about current operator
@@ -301,8 +303,8 @@ void get_op_usage(
     const Base* parameter = play->GetPar();
     // -----------------------------------------------------------------------
     // vecad information
-    size_t num_vecad      = play->num_vecad_vec_rec();
-    size_t num_vecad_ind  = play->num_vec_ind_rec();
+    size_t num_vecad      = play->num_var_vecad_rec();
+    size_t num_vecad_ind  = play->num_var_vecad_ind_rec();
     //
     vecad_used.resize(num_vecad);
     for(size_t i = 0; i < num_vecad; i++)
@@ -382,7 +384,7 @@ void get_op_usage(
         // (This only makes sense when NumRes(op) > 0.)
         usage_t use_result = op_usage[i_op];
         //
-        bool sum_op = false;
+        bool check_csum = false;
         switch( op )
         {
             // =============================================================
@@ -391,7 +393,7 @@ void get_op_usage(
 
             // Only one variable with index arg[0]
             case SubvpOp:
-            sum_op = true;
+            check_csum = cumulative_sum_op;
             //
             case AbsOp:
             case AcosOp:
@@ -421,7 +423,7 @@ void get_op_usage(
             if( use_result != usage_t(no_usage) )
             {   size_t j_op = random_itr.var2op(size_t(arg[0]));
                 op_inc_arg_usage(
-                    play, sum_op, i_op, j_op, op_usage, cexp_set
+                    play, check_csum, i_op, j_op, op_usage, cexp_set
                 );
             }
             break; // --------------------------------------------
@@ -429,7 +431,7 @@ void get_op_usage(
             // Only one variable with index arg[1]
             case AddpvOp:
             case SubpvOp:
-            sum_op = true;
+            check_csum = cumulative_sum_op;
             //
             case DisOp:
             case DivpvOp:
@@ -440,7 +442,7 @@ void get_op_usage(
             if( use_result != usage_t(no_usage) )
             {   size_t j_op = random_itr.var2op(size_t(arg[1]));
                 op_inc_arg_usage(
-                    play, sum_op, i_op, j_op, op_usage, cexp_set
+                    play, check_csum, i_op, j_op, op_usage, cexp_set
                 );
             }
             break; // --------------------------------------------
@@ -448,7 +450,7 @@ void get_op_usage(
             // arg[0] and arg[1] are the only variables
             case AddvvOp:
             case SubvvOp:
-            sum_op = true;
+            check_csum = cumulative_sum_op;
             //
             case DivvvOp:
             case MulvvOp:
@@ -459,7 +461,7 @@ void get_op_usage(
             {   for(size_t i = 0; i < 2; i++)
                 {   size_t j_op = random_itr.var2op(size_t(arg[i]));
                     op_inc_arg_usage(
-                        play, sum_op, i_op, j_op, op_usage, cexp_set
+                        play, check_csum, i_op, j_op, op_usage, cexp_set
                     );
                 }
             }
@@ -479,14 +481,14 @@ void get_op_usage(
                 if( arg[1] & 1 )
                 {   size_t j_op = random_itr.var2op(size_t(arg[2]));
                     op_inc_arg_usage(
-                        play, sum_op, i_op, j_op, op_usage, cexp_set
+                        play, check_csum, i_op, j_op, op_usage, cexp_set
                     );
                 }
                 // propgate from result to right argument
                 if( arg[1] & 2 )
                 {   size_t j_op = random_itr.var2op(size_t(arg[3]));
                     op_inc_arg_usage(
-                            play, sum_op, i_op, j_op, op_usage, cexp_set
+                            play, check_csum, i_op, j_op, op_usage, cexp_set
                     );
                 }
                 // are if_true and if_false cases the same variable
@@ -500,7 +502,7 @@ void get_op_usage(
                     bool can_skip = conditional_skip & (! same_variable);
                     can_skip     &= op_usage[j_op] == usage_t(no_usage);
                     op_inc_arg_usage(
-                        play, sum_op, i_op, j_op, op_usage, cexp_set
+                        play, check_csum, i_op, j_op, op_usage, cexp_set
                     );
                     if( can_skip )
                     {   // j_op corresponds to the value used when the
@@ -519,7 +521,7 @@ void get_op_usage(
                     bool can_skip = conditional_skip & (! same_variable);
                     can_skip     &= op_usage[j_op] == usage_t(no_usage);
                     op_inc_arg_usage(
-                        play, sum_op, i_op, j_op, op_usage, cexp_set
+                        play, check_csum, i_op, j_op, op_usage, cexp_set
                     );
                     if( can_skip )
                     {   // j_op corresponds to the value used when the
@@ -556,14 +558,14 @@ void get_op_usage(
                 {   // arg[1] is a variable
                     size_t j_op = random_itr.var2op(size_t(arg[1]));
                     op_inc_arg_usage(
-                        play, sum_op, i_op, j_op, op_usage, cexp_set
+                        play, check_csum, i_op, j_op, op_usage, cexp_set
                     );
                 }
                 if( arg[0] & 2 )
                 {   // arg[3] is a variable
                     size_t j_op = random_itr.var2op(size_t(arg[3]));
                     op_inc_arg_usage(
-                        play, sum_op, i_op, j_op, op_usage, cexp_set
+                        play, check_csum, i_op, j_op, op_usage, cexp_set
                     );
                 }
             }
@@ -584,7 +586,7 @@ void get_op_usage(
                 //
                 size_t j_op = random_itr.var2op(size_t(arg[1]));
                 op_inc_arg_usage(
-                    play, sum_op, i_op, j_op, op_usage, cexp_set
+                    play, check_csum, i_op, j_op, op_usage, cexp_set
                 );
             }
             break; // ----------------------------------------------
@@ -598,7 +600,7 @@ void get_op_usage(
                 //
                 size_t j_op = random_itr.var2op(size_t(arg[0]));
                 op_inc_arg_usage(
-                    play, sum_op, i_op, j_op, op_usage, cexp_set
+                    play, check_csum, i_op, j_op, op_usage, cexp_set
                 );
             }
             break; // ----------------------------------------------
@@ -615,7 +617,7 @@ void get_op_usage(
                 for(size_t i = 0; i < 2; i++)
                 {   size_t j_op = random_itr.var2op(size_t(arg[i]));
                     op_inc_arg_usage(
-                        play, sum_op, i_op, j_op, op_usage, cexp_set
+                        play, check_csum, i_op, j_op, op_usage, cexp_set
                     );
                 }
             }
@@ -679,7 +681,7 @@ void get_op_usage(
                 for(size_t i = 5; i < size_t(arg[2]); i++)
                 {   size_t j_op = random_itr.var2op(size_t(arg[i]));
                     op_inc_arg_usage(
-                        play, sum_op, i_op, j_op, op_usage, cexp_set
+                        play, check_csum, i_op, j_op, op_usage, cexp_set
                     );
                 }
             }
@@ -750,7 +752,7 @@ void get_op_usage(
                         {   CPPAD_ASSERT_UNKNOWN( atom_ix[j] > 0 );
                             if( depend_x[j] )
                             {   size_t j_op = random_itr.var2op(atom_ix[j]);
-                                op_inc_arg_usage(play, sum_op,
+                                op_inc_arg_usage(play, check_csum,
                                     last_atom_i_op, j_op, op_usage, cexp_set
                                 );
                             }
@@ -821,7 +823,7 @@ void get_op_usage(
             if( use_result )
             {   depend_y[atom_i] = true;
                 op_inc_arg_usage(
-                    play, sum_op, i_op, last_atom_i_op, op_usage, cexp_set
+                    play, check_csum, i_op, last_atom_i_op, op_usage, cexp_set
                 );
             }
             break; // --------------------------------------------------------
