@@ -1,7 +1,7 @@
 # ifndef CPPAD_LOCAL_PLAY_ATOM_OP_INFO_HPP
 # define CPPAD_LOCAL_PLAY_ATOM_OP_INFO_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -66,13 +66,13 @@ atomic_base<Base>* atom_op_info(
     //
     bool         set_null = false;
     size_t       type     = 0;          // set to avoid warning
-    std::string* name_ptr = CPPAD_NULL;
-    void*        v_ptr    = CPPAD_NULL; // set to avoid warning
+    std::string* name_ptr = nullptr;
+    void*        v_ptr    = nullptr; // set to avoid warning
     local::atomic_index<Base>(set_null, atom_index, type, name_ptr, v_ptr);
     if( type == 3 )
-        return CPPAD_NULL;
+        return nullptr;
 # ifndef NDEBUG
-    if( v_ptr == CPPAD_NULL )
+    if( v_ptr == nullptr )
     {   // atom_fun is null so cannot use atom_fun->atomic_name()
         std::string msg = atomic_base<Base>::class_name(atom_index)
             + ": atomic_base function has been deleted";
