@@ -1,5 +1,5 @@
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -12,9 +12,6 @@ in the Eclipse Public License, Version 2.0 are satisfied:
 /*
 $begin cppad_mat_mul.cpp$$
 $spell
-    resize
-    nr
-    nc
     cppad
     mul
     hpp
@@ -27,7 +24,6 @@ $spell
     CppAD
     dz
     typedef
-    enum
 $$
 
 $section CppAD Speed, Matrix Multiplication$$
