@@ -1,5 +1,5 @@
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -13,20 +13,17 @@ in the Eclipse Public License, Version 2.0 are satisfied:
 # include <cppad/speed/sparse_hes_fun.hpp>
 # include <cppad/speed/uniform_01.hpp>
 # include <cppad/utility/index_sort.hpp>
+# include <cppad/utility/time_test.hpp>
 
 # include "link_sparse_hessian.hpp"
 
-/*!
-\{
-\file link_sparse_hessian.cpp
-Defines and implement sparse Hessian speed link to package specific code.
-*/
 namespace { // BEGIN_EMPTY_NAMESPACE
 
 using CppAD::vector;
 
 /*
-$begin choose_row_col$$
+------------------------------------------------------------------------------
+$begin sparse_hessian_choose_row_col$$
 $spell
     Namespace
 $$
@@ -34,11 +31,11 @@ $$
 $section Randomly choose Hessian row and column indices$$
 
 $head Namespace$$
-This function is in the empty namespace; i.e., it can only be accessed
+This function is in the empty namespace; i.e., it is only accessed
 by functions in this file.
 
 $head Prototype$$
-$srcfile%speed/src/link_sparse_hessian.cpp%
+$srcthisfile%
     0%// BEGIN_choose_row_col%// END_choose_row_col%1
 %$$
 
@@ -114,31 +111,85 @@ void choose_row_col(
     }
 }
 } // END_EMPTY_NAMESPACE
-
-
 /*
-$begin available_sparse_hessian$$
+------------------------------------------------------------------------------
+$begin info_sparse_hessian$$
 $spell
     Namespace
     CppAD
-    bool
 $$
 
-$section Is Sparse Hessian Speed Test Available$$
+$section Sparse Hessian Speed Test Information$$
 
 $head Namespace$$
 This function is in the global namespace, not the CppAD namespace.
 
 $head Syntax$$
-$icode%available% = available_sparse_hessian()%$$
+$codei%info_spares_hessian(%size%, %n_color%)%$$
 
-$head available$$
-If the spare Hessian speed test is available for this package,
-the $code bool$$ value $icode available$$ is true.
-Otherwise it is false.
+$head size$$
+This $code size_t$$ value is equal to
+$cref/size/speed_time_callback/size/$$
+in the corresponding call to $code time_sparse_hessian_callback$$.
+
+$head n_color$$
+The input value of this $icode size_t$$ does not matter.
+Upon return, it is the value $cref/n_color/link_sparse_hessian/n_color/$$
+returned by the corresponding call to $code link_sparse_hessian$$.
 
 $end
 */
+void info_sparse_hessian(size_t size, size_t& n_color)
+{   size_t n      = size;
+    size_t repeat = 1;
+    vector<size_t> row, col;
+    choose_row_col(n, row, col);
+
+    // note that cppad/speed/sparse_hessian.cpp assumes that x.size()
+    // is the size corresponding to this test
+    vector<double> x(n);
+    size_t K = row.size();
+    vector<double> hessian(K);
+    link_sparse_hessian(n, repeat, row, col, x, hessian, n_color);
+    return;
+}
+// ---------------------------------------------------------------------------
+// The routines below are documented in dev_link.omh
+// ---------------------------------------------------------------------------
+namespace {
+    void time_sparse_hessian_callback(size_t size, size_t repeat)
+    {
+        static size_t previous_size = 0;
+        static vector<size_t> row, col;
+        //
+        // free statically allocated memory
+        if( size == 0 && repeat == 0 )
+        {   row.clear();
+            col.clear();
+            previous_size = size;
+            return;
+        }
+
+        size_t n = size;
+        vector<double> x(n);
+        if( size != previous_size )
+        {   choose_row_col(n, row, col);
+            previous_size = size;
+        }
+        size_t K = row.size();
+        vector<double> hessian(K);
+# ifndef NDEBUG
+        for(size_t k = 0; k < K; k++)
+            CPPAD_ASSERT_UNKNOWN( col[k] <= row[k] );
+# endif
+
+        // note that cppad/sparse_hessian.cpp assumes that x.size() == size
+        size_t n_color;
+        link_sparse_hessian(n, repeat, row, col, x, hessian, n_color);
+        return;
+    }
+}
+// ---------------------------------------------------------------------------
 bool available_sparse_hessian(void)
 {
     size_t n      = 2;
@@ -152,34 +203,7 @@ bool available_sparse_hessian(void)
     size_t n_color;
     return link_sparse_hessian(n, repeat, row, col, x, hessian, n_color);
 }
-/*
-$begin correct_sparse_hessian$$
-$spell
-    Namespace
-    CppAD
-    bool
-$$
-
-$section Does Sparse Hessian Pass Correctness Test$$
-
-$head Namespace$$
-This function is in the global namespace, not the CppAD namespace.
-
-$head Syntax$$
-$icode%ok% = correct_sparse_hessian(%is_package_double%)%$$
-
-$head is_package_double$$
-If the $code bool$$ value $code is_package_double$$ is true,
-we are checking function values.
-Otherwise, we are checking derivative values.
-
-$head ok$$
-If the spare Hessian correctness test passed,
-the $code bool$$ value $icode ok$$ is true.
-Otherwise it is false.
-
-$end
-*/
+// ---------------------------------------------------------------------------
 bool correct_sparse_hessian(bool is_package_double)
 {
     double eps99 = 99.0 * std::numeric_limits<double>::epsilon();
@@ -218,101 +242,11 @@ bool correct_sparse_hessian(bool is_package_double)
 
     return ok;
 }
-/*
-$begin speed_sparse_hessian$$
-$spell
-    Namespace
-    CppAD
-$$
-
-$section Drive Sparse Hessian for Speed Testing$$
-
-$head Namespace$$
-This function is in the global namespace, not the CppAD namespace.
-
-$head Syntax$$
-$codei%speed_sparse_hessian(%size%, %repeat%)%$$
-
-$head size$$
-This $code size_t$$ value
-is the dimension of the argument space for function we are taking
-the Hessian of.
-
-$head repeat$$
-This $code size_t$$ value
-is the number of times to repeat the speed test.
-
-$end
-*/
-void speed_sparse_hessian(size_t size, size_t repeat)
-{
-    static size_t previous_size = 0;
-    static vector<size_t> row, col;
-    //
-    // free statically allocated memory
-    if( size == 0 && repeat == 0 )
-    {   row.clear();
-        col.clear();
-        previous_size = size;
-        return;
-    }
-
-    size_t n = size;
-    vector<double> x(n);
-    if( size != previous_size )
-    {   choose_row_col(n, row, col);
-        previous_size = size;
-    }
-    size_t K = row.size();
-    vector<double> hessian(K);
-# ifndef NDEBUG
-    for(size_t k = 0; k < K; k++)
-        CPPAD_ASSERT_UNKNOWN( col[k] <= row[k] );
-# endif
-
-    // note that cppad/sparse_hessian.cpp assumes that x.size() == size
-    size_t n_color;
-    link_sparse_hessian(n, repeat, row, col, x, hessian, n_color);
-    return;
-}
-/*
-$begin info_sparse_hessian$$
-$spell
-    Namespace
-    CppAD
-$$
-
-$section Sparse Hessian Speed Test Information$$
-
-$head Namespace$$
-This function is in the global namespace, not the CppAD namespace.
-
-$head Syntax$$
-$codei%info_spares_hessian(%size%, %n_color%)%$$
-
-$head size$$
-This $code size_t$$ value is equal to
-$cref/size/speed_sparse_hessian/size/$$
-in the corresponding call to $code speed_sparse_hessian$$.
-
-$head n_color$$
-The input value of this $icode size_t$$ does not matter.
-Upon return, it is the value $cref/n_color/link_sparse_hessian/n_color/$$
-returned by the corresponding call to $code link_sparse_hessian$$.
-
-$end
-*/
-void info_sparse_hessian(size_t size, size_t& n_color)
-{   size_t n      = size;
-    size_t repeat = 1;
-    vector<size_t> row, col;
-    choose_row_col(n, row, col);
-
-    // note that cppad/speed/sparse_hessian.cpp assumes that x.size()
-    // is the size corresponding to this test
-    vector<double> x(n);
-    size_t K = row.size();
-    vector<double> hessian(K);
-    link_sparse_hessian(n, repeat, row, col, x, hessian, n_color);
-    return;
+// ---------------------------------------------------------------------------
+double time_sparse_hessian(double time_min, size_t size)
+{   double time = CppAD::time_test(
+        time_sparse_hessian_callback, time_min, size
+    );
+    time_sparse_hessian_callback(0, 0);
+    return time;
 }
