@@ -1,7 +1,7 @@
 # ifndef CPPAD_TEST_MORE_DEPRECATED_ATOMIC_TWO_MAT_MUL_HPP
 # define CPPAD_TEST_MORE_DEPRECATED_ATOMIC_TWO_MAT_MUL_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-18 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -13,7 +13,7 @@ in the Eclipse Public License, Version 2.0 are satisfied:
 ---------------------------------------------------------------------------- */
 
 /*
-$begin atomic_mat_mul.hpp$$
+$begin atomic_three_mat_mul.hpp$$
 $spell
     Taylor
     ty
@@ -28,7 +28,7 @@ $$
 $section Matrix Multiply as an Atomic Operation$$
 
 $head See Also$$
-$cref atomic_eigen_mat_mul.hpp$$
+$cref atomic_two_eigen_mat_mul.hpp$$
 
 $head Matrix Dimensions$$
 This example puts the matrix dimensions in the atomic function arguments,
